# Master Electron - Course Code

Demo project modified from: https://github.com/electron/electron-quick-start

*Modified for improved screen real estate and for the sake of consistent versioning.*

![Master Electron](https://raw.githubusercontent.com/stackacademytv/master-electron/master/splash.png)
